@@ -17,24 +17,39 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
 from enum import Enum
+from typing import List, Optional, Union
 
-
-class Categories(Enum):
-    cuddle = "cuddle"
-    feed = "feed"
-    hug = "hug"
-    kiss = "kiss"
-    nekos = "nekos"
-    pat = "pat"
-    poke = "poke"
-    slap = "slap"
-    tickle = "tickle"
-
-    @classmethod
-    def has_value(cls, value: str):
-        return value in cls.__members__
+CATEGORIES = (
+    "baka",
+    "cry",
+    "cuddle",
+    "dance",
+    "feed",
+    "hug",
+    "kiss",
+    "laugh",
+    "nekos",
+    "pat",
+    "poke",
+    "slap",
+    "smile",
+    "smug",
+    "tickle",
+    "wave",
+)
 
 
 class Result:
+    """Represents a response from the API.
+    
+    Attributes
+    ----------
+    url: Optional[Union[str, List[str]]]
+        The image(s) url(s).
+    """
+
     def __init__(self, data: dict):
-        self.url = data.get("url")
+        self.url: Optional[Union[str, List[str]]] = data.get("url")
+
+    def __repr__(self) -> str:
+        return f"<Result url={self.url}>"
